@@ -70,15 +70,8 @@ def error(message: str, code: int):
 def root():
     global db_path
 
-    sub_n: int
-    jrn_n: int
-    usr_n: int
-    version: str
     with FADatabase(db_path) as db:
-        sub_n = len(db.submissions)
-        jrn_n = len(db.journals)
-        usr_n = len(db.users)
-        version = db.settings["VERSION"]
+        sub_n, jrn_n, usr_n, version = len(db.submissions), len(db.journals), len(db.users), db.settings["VERSION"]
 
     return render_template(
         "root.html",
@@ -99,24 +92,25 @@ def load_user(username: str, _cache=None) -> Optional[dict]:
 
 @cache
 def load_user_stats(username: str, _cache=None) -> dict[str, int]:
+    global db_path
     username = clean_username(username)
     stats: dict[str, int] = {}
     with FADatabase(db_path) as db:
         stats["gallery"] = db.submissions.select(
             {"replace(lower(author), '_', '')": username, "folder": "gallery"}, ["count(ID)"]
-        ).fetchone()[0]
+        ).cursor.fetchone()[0]
         stats["scraps"] = db.submissions.select(
             {"replace(lower(author), '_', '')": username, "folder": "scraps"}, ["count(ID)"]
-        ).fetchone()[0]
+        ).cursor.fetchone()[0]
         stats["favorites"] = db.submissions.select(
             {"favorite": f"%|{username}|%"}, ["count(ID)"], like=True
-        ).fetchone()[0]
+        ).cursor.fetchone()[0]
         stats["mentions"] = db.submissions.select(
             {"mentions": f"%|{username}|%"}, ["count(ID)"], like=True
-        ).fetchone()[0]
+        ).cursor.fetchone()[0]
         stats["journals"] = db.journals.select(
             {"replace(lower(author), '_', '')": username}, ["count(ID)"]
-        ).fetchone()[0]
+        ).cursor.fetchone()[0]
     return stats
 
 
@@ -138,7 +132,7 @@ def load_prev_next(table: str, id_: int) -> tuple[int, int]:
             ["LAG(ID, 1, 0) over (order by ID)", "LEAD(ID, 1, 0) over (order by ID)"],
             order=[f"ABS(ID - {id_})"],
             limit=1
-        ).fetchone() if item else (0, 0)
+        ).cursor.fetchone() if item else (0, 0)
 
 
 @cache
@@ -195,9 +189,7 @@ def search_table(table: str, sort: str, order: str, params_serialised: str = "{}
             query: str = " or ".join(map(lambda q: f"({q})", params["sql"]))
             query = re_sub(r"any(?= (!?=|(not )?(like|glob)|[<>]=?))", f"({'||'.join(cols_table)})", query)
             return (
-                list(db_table.cursor_to_dict(
-                    db_table.select_sql(query, columns=cols_results, order=[f"{sort} {order}"]),
-                    cols_results)),
+                list(db_table.select_sql(query, columns=cols_results, order=[f"{sort} {order}"])),
                 cols_table + ["any"],
                 cols_results,
                 cols_list,
@@ -215,9 +207,7 @@ def search_table(table: str, sort: str, order: str, params_serialised: str = "{}
             del params["any"]
 
         return (
-            list(db_table.cursor_to_dict(
-                db_table.select(params, cols_results, like=True, order=[f"{sort} {order}"]),
-                cols_results)),
+            list(db_table.select(params, cols_results, like=True, order=[f"{sort} {order}"])),
             cols_table + ["any"],
             cols_results,
             cols_list,
@@ -235,7 +225,6 @@ def response_minify(response):
     return response
 
 
-@cache
 @app.route("/user/<username>")
 def user(username: str):
     global db_path
@@ -380,7 +369,6 @@ def search(table: str):
     )
 
 
-@cache
 @app.route("/journal/<int:id_>/")
 def journal(id_: int):
     if (jrnl := load_item(journals_table, id_)) is None:
@@ -421,7 +409,6 @@ def submission_view(id_: int):
     return redirect(f"/submission/{id_}")
 
 
-@cache
 @app.route("/submission/<int:id_>/")
 def submission(id_: int):
     if (sub := load_item(submissions_table, id_)) is None:
@@ -458,26 +445,26 @@ def submission_file(id_: int, filename: str = None):
 @app.route("/submission/<int:id_>/thumbnail/<int:x>/<string:filename>")
 @app.route("/submission/<int:id_>/thumbnail/<int:x>x<int:y>/")
 @app.route("/submission/<int:id_>/thumbnail/<int:x>x<int:y>/<string:filename>")
-def submission_thumbnail(id_: int, x: int = 150, y: int = None, filename: str = None):
+def submission_thumbnail(id_: int, x: int = None, y: int = None, filename: str = None):
     sub_type, sub_filesaved, sub_file, sub_thumb = load_submission_file(id_)
-    y = x if y is None else y
 
     if sub_type is None or sub_filesaved == 0:
         return abort(404)
     elif sub_filesaved % 10 == 1 and isfile(sub_thumb):
-        f_obj: BytesIO = BytesIO()
+        if not x:
+            return send_file(sub_thumb, attachment_filename=filename, mimetype="image/jpeg")
+
         with Image.open(sub_thumb) as img:
-            img.thumbnail((x, y)) if img.width > x or img.height > y else None
-            img.save(f_obj, "jpeg")
-        f_obj.seek(0)
-        return send_file(f_obj, attachment_filename=filename, mimetype="image/jpeg")
+            img.thumbnail((x, y or x))
+            img.save(f_obj := BytesIO(), ext := img.format, quality=95)
+            f_obj.seek(0)
+            return send_file(f_obj, attachment_filename=filename, mimetype=f"image/{ext.lower()}")
     elif sub_filesaved >= 10 and sub_type == "image" and isfile(sub_file):
-        f_obj: BytesIO = BytesIO()
         with Image.open(sub_file) as img:
-            img.thumbnail((x, y))
-            img.save(f_obj, ext := img.format)
-        f_obj.seek(0)
-        return send_file(f_obj, attachment_filename=filename, mimetype=f"image/{ext.lower()}")
+            img.thumbnail((x or 400, y or x or 400))
+            img.save(f_obj := BytesIO(), ext := img.format, quality=95)
+            f_obj.seek(0)
+            return send_file(f_obj, attachment_filename=filename, mimetype=f"image/{ext.lower()}")
     else:
         return abort(404)
 
